@@ -154,6 +154,8 @@ cleanup (void)
   g_list_free (pending);
   pending = NULL;
   track = NULL;
+  /* TODO: find out why GTK+ needs this to work (see #364371) */
+  gtk_button_set_label (GTK_BUTTON (extract_button), _("Extract"));
   gtk_button_set_label (GTK_BUTTON (extract_button), SJ_STOCK_EXTRACT);
   
   /* Clear the Status bar */
@@ -450,7 +452,7 @@ on_main_window_focus_in (GtkWidget * widget, GdkEventFocus * event, gpointer dat
  * Show the "Finished!" dialog, allowing the user to open Nautilus if he wants.
  */
 static void
-show_finished_dialog (void)
+show_finished_dialog (const TrackDetails *track)
 {
   GtkWidget *dialog;
   int result;
@@ -462,12 +464,16 @@ show_finished_dialog (void)
 
   cleanup ();
 
+  char *message;
+  message = g_strdup_printf (_("%s has been copied successfully."), track->album->title);
+
   dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
                                    GTK_DIALOG_DESTROY_WITH_PARENT,
                                    GTK_MESSAGE_INFO,
                                    GTK_BUTTONS_NONE,
-                                   /* TODO: need to have a better message here */
-                                   _("The tracks have been copied successfully."));
+                                   (message));
+
+  g_free (message);
   /* If we eject when finished, eject now, otherwise add a button */
   if (eject_finished) {
     nautilus_burn_drive_eject (drive);
@@ -513,7 +519,7 @@ on_completion_cb (SjExtractor *extractor, gpointer data)
   }
   
   if (pending == NULL) {
-    show_finished_dialog ();
+    show_finished_dialog (track);
     if (autostart) {
       gtk_main_quit ();
     }
@@ -613,6 +619,8 @@ on_extract_activate (GtkWidget *button, gpointer user_data)
   }
   
   /* Change the label to Stop while extracting*/
+  /* TODO: find out why GTK+ needs this to work (see #364371) */
+  gtk_button_set_label (GTK_BUTTON (extract_button), _("Stop"));
   gtk_button_set_label (GTK_BUTTON (extract_button), GTK_STOCK_STOP);
   
   /* Reset the progress dialog */
