@@ -35,6 +35,7 @@
 #include <libgnome/gnome-help.h>
 #include <libgnome/gnome-url.h>
 #include <libgnomeui/gnome-ui-init.h>
+#include <libgnomeui/gnome-authentication-manager.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <profiles/gnome-media-profiles.h>
 #include <gst/gst.h>
@@ -48,6 +49,7 @@
 #include "sj-structures.h"
 #include "sj-error.h"
 #include "sj-util.h"
+#include "sj-main.h"
 #include "sj-prefs.h"
 #include "sj-play.h"
 #include "bacon-volume.h"
@@ -78,7 +80,8 @@ GtkListStore *track_store;
 static BaconMessageConnection *connection;
 GtkCellRenderer *toggle_renderer, *title_renderer, *artist_renderer;
 
-const char *base_uri, *path_pattern, *file_pattern;
+const char *path_pattern, *file_pattern;
+char *base_uri;
 NautilusBurnDrive *drive = NULL;
 gboolean strip_chars;
 gboolean eject_finished;
@@ -91,7 +94,7 @@ static char *current_submit_url = NULL;
 
 gboolean autostart = FALSE, autoplay = FALSE;
 
-static guint debug_flags;
+static guint debug_flags = 0;
 
 #define DEFAULT_PARANOIA 4
 #define RAISE_WINDOW "raise-window"
@@ -135,7 +138,7 @@ sj_stock_init (void)
   static gboolean initialized = FALSE;
   static GtkIconFactory *sj_icon_factory = NULL;
 
-  static GtkStockItem sj_stock_items[] =
+  static const GtkStockItem sj_stock_items[] =
   {
     { SJ_STOCK_PLAYING, NULL, 0, 0, NULL },
     { SJ_STOCK_RECORDING, NULL, 0, 0, NULL },
@@ -188,7 +191,6 @@ static void sj_debug_init (void)
 {
   const char *str;
   const GDebugKey debug_keys[] = {
-    { "all", DEBUG_ALL },
     { "cd", DEBUG_CD },
     { "metadata", DEBUG_METADATA },
     { "playing", DEBUG_PLAYING },
@@ -196,14 +198,9 @@ static void sj_debug_init (void)
   };
 
   str = g_getenv ("SJ_DEBUG");
-  if (str != NULL) {
+  if (str) {
     debug_flags = g_parse_debug_string (str, debug_keys, G_N_ELEMENTS (debug_keys));
-  } else {
-    debug_flags = 0;
   }
-  
-  if (debug_flags & DEBUG_ALL)
-    debug_flags = 0xFFFFFFFF;
 }
 
 static void error_on_start (GError *error)
@@ -388,6 +385,8 @@ static void update_ui_for_album (AlbumDetails *album)
     gtk_entry_set_text (GTK_ENTRY (artist_entry), album->artist);
     g_signal_handlers_unblock_by_func (title_entry, on_title_edit_changed, NULL);
     g_signal_handlers_unblock_by_func (artist_entry, on_artist_edit_changed, NULL);
+    /* Clear the genre field, it's from the user */
+    gtk_entry_set_text (GTK_ENTRY (genre_entry), "");
 
     gtk_widget_set_sensitive (title_entry, TRUE);
     gtk_widget_set_sensitive (artist_entry, TRUE);
@@ -457,7 +456,7 @@ AlbumDetails* multiple_album_dialog(GList *albums)
 
   if (dialog == NULL) {
     GtkTreeViewColumn *column;
-    GtkCellRenderer *text_renderer = text_renderer = gtk_cell_renderer_text_new ();
+    GtkCellRenderer *text_renderer = gtk_cell_renderer_text_new ();
 
     dialog = glade_xml_get_widget (glade, "multiple_dialog");
     g_assert (dialog != NULL);
@@ -517,10 +516,11 @@ AlbumDetails* multiple_album_dialog(GList *albums)
 void baseuri_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
 {
   g_assert (strcmp (entry->key, GCONF_BASEURI) == 0);
+  g_free (base_uri);
   if (entry->value == NULL) {
-    base_uri = gnome_vfs_get_uri_from_local_path (g_get_home_dir ());
+    base_uri = sj_get_default_music_directory ();
   } else {
-    base_uri = gconf_value_get_string (entry->value);
+    base_uri = g_strdup (gconf_value_get_string (entry->value));
   }
   /* TODO: sanity check the URI somewhat */
 }
@@ -779,6 +779,9 @@ media_removed_cb (NautilusBurnDrive *drive,
     /* FIXME: recover? */
   }
 
+  /* first make sure we're not playing */
+  stop_playback ();
+
   sj_debug (DEBUG_CD, "Media removed from device %s\n", nautilus_burn_drive_get_device (drive));
   stop_ui_hack ();
   update_ui_for_album (NULL);
@@ -802,7 +805,23 @@ set_drive_from_device (const char *device)
 
   monitor = nautilus_burn_get_drive_monitor ();
   drive = nautilus_burn_drive_monitor_get_drive_for_device (monitor, device);
-  g_assert (drive);
+  if (! drive) {
+    GtkWidget *dialog;
+    char *message;
+    message = g_strdup_printf (_("Sound Juicer could not use the CD-ROM device '%s'"), device);
+    dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
+                                     GTK_DIALOG_DESTROY_WITH_PARENT,
+                                     GTK_MESSAGE_ERROR,
+                                     GTK_BUTTONS_CLOSE,
+                                     "<b>%s</b>\n\n%s",
+                                     message,
+                                     _("HAL daemon may not be running."));
+    g_free (message);
+    gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), TRUE);
+    gtk_dialog_run (GTK_DIALOG (dialog));
+    gtk_widget_destroy (dialog);
+    return;
+  }
 
   is_locked = nautilus_burn_drive_lock (drive, _("Extracting audio from CD"), &reason);
   if (! is_locked) {
@@ -824,7 +843,11 @@ set_device (const char* device, gboolean ignore_no_media)
   } else if (access (device, R_OK) != 0) {
     GtkWidget *dialog;
     char *message;
+    const char *error;
+    
+    error = g_strerror (errno);
     message = g_strdup_printf (_("Sound Juicer could not access the CD-ROM device '%s'"), device);
+    
     dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
                                      GTK_DIALOG_DESTROY_WITH_PARENT,
                                      GTK_MESSAGE_ERROR,
@@ -833,8 +856,9 @@ set_device (const char* device, gboolean ignore_no_media)
                                      _("Could not read the CD"),
                                      message,
                                      _("Reason"),
-                                     strerror (errno));
+                                     error);
     g_free (message);
+
     gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), TRUE);
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
@@ -972,11 +996,12 @@ http_proxy_setup (GConfClient *client)
   if (!gconf_client_get_bool (client, GCONF_HTTP_PROXY_ENABLE, NULL)) {
     sj_metadata_set_proxy (metadata, NULL);
   } else {
-    const char *host;
+    char *host;
     int port;
 
     host = gconf_client_get_string (client, GCONF_HTTP_PROXY, NULL);
     sj_metadata_set_proxy (metadata, host);
+    g_free (host);
     port = gconf_client_get_int (client, GCONF_HTTP_PROXY_PORT, NULL);
     sj_metadata_set_proxy_port (metadata, port);
   }
@@ -1214,7 +1239,7 @@ void on_contents_activate(GtkWidget *button, gpointer user_data) {
 }
 
 
-static const char* genres[] = {
+static const char* const genres[] = {
   "Ambient",
   "Blues",
   "Classical",
@@ -1236,7 +1261,7 @@ static const char* genres[] = {
 
 static GtkTreeModel* create_genre_list(void) {
   GtkListStore *store;
-  const char **g = genres;
+  const char * const *g = genres;
 
   store = gtk_list_store_new (1, G_TYPE_STRING);
 
@@ -1301,12 +1326,15 @@ int main (int argc, char **argv)
     { NULL }
   };
 
+  if (!g_thread_supported ()) g_thread_init (NULL);
+
   bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  ctx = g_option_context_new (_("- Extract music from your CDs"));
+  ctx = g_option_context_new (N_("- Extract music from your CDs"));
   g_option_context_add_main_entries (ctx, entries, GETTEXT_PACKAGE);  
+  g_option_context_set_translation_domain(ctx, GETTEXT_PACKAGE);
   g_option_context_add_group (ctx, gst_init_get_option_group ());
   g_option_context_set_ignore_unknown_options (ctx, TRUE);
 
@@ -1319,6 +1347,8 @@ int main (int argc, char **argv)
 
   g_set_application_name (_("Sound Juicer"));
 
+  gnome_authentication_manager_init ();
+
   sj_debug_init ();
 
   sj_stock_init ();
@@ -1337,11 +1367,6 @@ int main (int argc, char **argv)
   }
 
   metadata = SJ_METADATA (sj_metadata_musicbrainz_new ());
-  error = sj_metadata_get_new_error (metadata);
-  if (error) {
-    error_on_start (error);
-    exit (1);
-  }
   g_signal_connect (metadata, "metadata", G_CALLBACK (metadata_cb), NULL);
 
   gconf_client = gconf_client_get_default ();
@@ -1536,6 +1561,7 @@ int main (int argc, char **argv)
 
   nautilus_burn_shutdown ();
 
+  g_free (base_uri);
   g_object_unref (metadata);
   g_object_unref (extractor);
   g_object_unref (gconf_client);
